@@ -4,7 +4,7 @@
  * Gnome Chemisty Utils
  * crystaldoc.h 
  *
- * Copyright (C) 2002-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,6 +33,7 @@
 #include "crystalline.h"
 #include "crystalcleavage.h"
 #include "document.h"
+#include <gcu/gldocument.h>
 
 namespace gcu
 {
@@ -77,13 +78,13 @@ enum gcLattices {cubic=0,
 /*!\class CrystalDoc gcu/crystaldoc.h
 The document containing the crystal structure.
 */				 
-class CrystalDoc: public Document
+class CrystalDoc: public GLDocument
 {
 public:
 /*!
 The constructor of CrystalDoc
 */
-	CrystalDoc ();
+	CrystalDoc (Application *App);
 /*!
 The destructor of CrystalDoc
 */
@@ -110,22 +111,10 @@ everything and updates all the views.
 */
 	CrystalView* GetView ();
 /*!
-@return true if the document has been modified, false if not.
-*/
-	bool IsDirty () {return m_bDirty;}
-/*!
-Signals the document as modified since the last saving operation.
-*/
-	virtual void SetDirty ();
-/*!
 Draws the document using OpenGL primitives.
 */
 	void Draw ();
 /*!
-@return the largest distance from an object displayed in the document to the center of the model.
-*/
-	gdouble GetMaxDist () {return m_dDist;}
-/*!
 Creates a view of the document. This method should be overrided by programs deriving a new view class from
 CrystalView.
 
@@ -238,10 +227,6 @@ The maximum z coordinate in the representation of the crystal structure.
 */
 	gdouble m_zmax;
 /*!
-The maximum distance between an object and the center.
-*/
-	gdouble m_dDist; //maximum distance between an object and the center
-/*!
 true if cleavages must not change positions in the view.
 */
 	gboolean m_bFixedSize;  //true if cleavages must not change positions in the view
@@ -269,17 +254,8 @@ List of the cleavages defined.
 List of the views of the document.
 */
 	list <CrystalView *> m_Views;
-/*!
-true if the document has changed since the last saving. Changing the orientation of the model
-in one of the views is considered as a change.
-*/
-	bool m_bDirty;
-/*!
-true if the document does not contain anything displayable.
-*/
-	bool m_bEmpty;
 };
-	
+
 } //namespace gcu
 
 #endif //CRYSTAL_DOC_H
