@@ -4,9 +4,7 @@
  * Gnome Chemistry Utils
  * object.h 
  *
- * Copyright (C) 2002-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -45,7 +43,7 @@ using namespace std;
 namespace gcu
 {
 
-/*!\enum TypeId
+/*!\enum GcuTypeId
 This enumeration is used to determine the type of an Object instance.
 Possible values are:
 	- NoType: invalid type
@@ -69,7 +67,7 @@ Possible values are:
 Some types are not used in  the Gnome Chemistry Utils, but only in GChemPaint
 and might disappear from this list in future versions and replaced by dynamically created types.
 */	
-enum
+enum GcuTypeId
 {
 	NoType,
 	AtomType,
@@ -89,6 +87,10 @@ enum
 	OtherType
 };
 
+/*!
+The type of an object instance. Either predefined types are defined in the enum above
+or dynamically defined types by calls to Object::AddType.
+*/
 typedef unsigned TypeId;
 
 /*!\enum RuleId
@@ -111,6 +113,10 @@ enum RuleId
 	RuleMustBeIn
 };
 
+/*!
+The types of the signals used in Object::EmitSignal() and Object::OnSignal(). Each signal
+must type be retrieved from a call to Object::CreateNewSignalId().
+*/
 typedef unsigned SignalId;
 
 class Document;
