@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * chemistry/xml-utils.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -201,7 +201,7 @@ bool ReadRadius (xmlNodePtr node, GcuAtomicRadius& radius)
 		radius.value.value = strtod (tmp, &end);
 		dot = strchr (tmp, '.');
 		radius.value.prec = (dot)? end - dot - 1: 0;
-		radius.scale = g_strdup ("custom");
+		radius.scale = "custom";
 		xmlFree(tmp);
 	} else {
 		if (tmp)
@@ -230,19 +230,19 @@ bool WriteRadius (xmlDocPtr xml, xmlNodePtr node, const GcuAtomicRadius& radius)
 		tmp = NULL;
 		break;
 	case GCU_ATOMIC:
-		tmp = (char*) "atomic";
+		tmp = "atomic";
 		break;
 	case GCU_IONIC:
-		tmp = (char*) "ionic";
+		tmp = "ionic";
 		break;
 	case GCU_METALLIC:
-		tmp = (char*) "metallic";
+		tmp = "metallic";
 		break;
 	case GCU_COVALENT:
-		tmp = (char*) "covalent";
+		tmp = "covalent";
 		break;
 	case GCU_VAN_DER_WAALS:
-		tmp = (char*) "vdW";
+		tmp = "vdW";
 		break;
 	default:
 		tmp = NULL;
