@@ -32,7 +32,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
-gc3dApplication::gc3dApplication (): Application (_("GChem3D Viewer"))
+gc3dApplication::gc3dApplication (): Application (_("GChem3D Viewer"), DATADIR, "gchem3d-viewer-unstable")
 {
 }
 
@@ -50,7 +50,7 @@ gc3dDocument *gc3dApplication::OnFileNew ()
 
 void gc3dApplication::OnFileOpen (gc3dDocument *Doc)
 {
-	list<char const*> l;
+	list<string> l;
 	l.push_front ("chemical/x-cml");
 	l.push_front ("chemical/x-mdl-molfile");
 	l.push_front ("chemical/x-pdb");
@@ -114,7 +114,7 @@ bool gc3dApplication::FileProcess (const gchar* filename, const gchar* mime_type
 			if (vrml)
 				pDoc->OnExportVRML (filename2);
 			else
-				pDoc->GetView ()->SaveAsImage (filename2, pixbuf_type, options, GetImageResolution ());
+				pDoc->GetView ()->SaveAsImage (filename2, pixbuf_type, options, GetImageWidth (), GetImageHeight ());
 		}
 	} else {
 		if (pDoc && !pDoc->IsEmpty ())
@@ -139,10 +139,10 @@ void gc3dApplication::OnSaveAsImage (gc3dDocument *Doc)
 {
 	if (!Doc)
 		return;
-	list<char const*> l;
+	list<string> l;
 	map<string, GdkPixbufFormat*>::iterator i, end = m_SupportedPixbufFormats.end ();
 	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
 		l.push_front ((*i).first.c_str ());
 	l.push_front ("model/vrml");
-	FileChooser (this, true, l, Doc, _("Save as image"), GetImageResolutionWidget ());
+	FileChooser (this, true, l, Doc, _("Save as image"), GetImageSizeWidget ());
 }
