@@ -35,6 +35,7 @@
 #include "globals.h"
 #include <libgnomevfs/gnome-vfs-init.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <glib/gi18n.h>
 
 using namespace gcu;
 using namespace std;
@@ -114,10 +115,6 @@ int main(int argc, char *argv[])
 	GOptionContext *context;
 	GError *error = NULL;
 
-	bindtextdomain(GETTEXT_PACKAGE, DATADIR"/locale");
-#ifdef ENABLE_NLS
-	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-#endif
 	textdomain(GETTEXT_PACKAGE);
 
 	gtk_init (&argc, &argv);
